@@ -9,7 +9,7 @@ use strict;
 use warnings;
 
 BEGIN {
-   our $VERSION = '0.61';
+   our $VERSION = '0.62';
 }
 
 use Carp;
@@ -176,16 +176,6 @@ sub new
       return 1;
    } );
 
-   $term->bind_event( mouse => sub {
-      $weakself or return;
-      my ( $term, $ev, $info ) = @_;
-      Tickit::Debug->log( Im => "Mouse event %s => %s @%d,%d (mod=%d)",
-         map { $info->$_ } qw( type button col line mod ) ) if DEBUG;
-      $weakself->on_mouse( $info );
-
-      return 1;
-   } );
-
    $self->set_root_widget( $args{root} ) if defined $args{root};
 
    return $self;
@@ -309,8 +299,6 @@ sub on_key
 
    my $str = $info->str;
 
-   $self->rootwin->_handle_key( $info ) and return;
-
    if( exists $self->{key_binds}{$str} ) {
       $self->{key_binds}{$str}->( $self, $str ) and return;
    }
@@ -348,56 +336,6 @@ sub bind_key
    }
 }
 
-sub on_mouse
-{
-   my $self = shift;
-   my ( $info ) = @_;
-
-   my $type = $info->type;
-   if( $type eq "press" ) {
-      # Save the mouse press location in case of drag
-      $self->{mouse_last_press} = [ $info->button, $info->line, $info->col ];
-   }
-   elsif( $type eq "drag" and !$self->{mouse_dragging} ) {
-      my $start_info = Tickit::Event::Mouse->_new(
-         drag_start => $info->button, @{$self->{mouse_last_press}}[1,2], $info->mod,
-      );
-
-      my $win = $self->rootwin->_handle_mouse( $start_info );
-      $self->{drag_source_window} = $win;
-
-      $self->{mouse_dragging} = 1;
-   }
-   elsif( $type eq "release" and $self->{mouse_dragging} ) {
-      my $drop_info = Tickit::Event::Mouse->_new(
-         drag_drop => $info->button, $info->line, $info->col, $info->mod,
-      );
-
-      $self->rootwin->_handle_mouse( $drop_info );
-
-      if( my $win = $self->{drag_source_window} ) {
-         my $stop_info = Tickit::Event::Mouse->_new(
-            drag_stop => $info->button, $info->line - $win->abs_top, $info->col - $win->abs_left, $info->mod,
-         );
-         $win->_handle_mouse( $stop_info );
-      }
-
-      $self->{mouse_dragging} = 0;
-   }
-
-   my $win = $self->rootwin->_handle_mouse( $info );
-
-   my $srcwin;
-   if( $type eq "drag" and
-       $srcwin = $self->{drag_source_window} and
-       !$win || ( $win && $win != $srcwin ) ) {
-      my $outside_info = Tickit::Event::Mouse->_new(
-         drag_outside => $info->button, $info->line - $srcwin->abs_top, $info->col - $srcwin->abs_left, $info->mod,
-      );
-      $srcwin->_handle_mouse( $outside_info );
-   }
-}
-
 =head2 rootwin
 
    $tickit->rootwin
@@ -495,6 +433,14 @@ C<teardown_term>.
 
 =cut
 
+sub _flush
+{
+   my $self = shift;
+
+   $self->_flush_later if @{ $self->{todo_queue} };
+   $self->rootwin->flush if $self->rootwin;
+}
+
 sub _tick
 {
    my $self = shift;
@@ -513,7 +459,7 @@ sub _tick
       shift( @$timer_queue )->code->();
    }
 
-   $self->_flush_later if @{ $self->{todo_queue} };
+   $self->_flush;
 }
 
 sub tick
@@ -575,7 +521,7 @@ sub run
       die @_;
    };
 
-   $self->_flush_later if @{ $self->{todo_queue} };
+   $self->_flush;
 
    local $self->{keep_running} = 1;
    $self->_tick while( $self->{keep_running} );
